==> fr.opensagres.poi.xwpf.converter.xhtml-2.0.1-sources.jar: fr/opensagres/poi/xwpf/converter/xhtml/internal/styles/CSSStylePropertyConstants.java <==
/**
 * Copyright (C) 2011-2015 The XDocReport Team <xdocreport@googlegroups.com>
 *
 * All rights reserved.
 *
 * Permission is hereby granted, free  of charge, to any person obtaining
 * a  copy  of this  software  and  associated  documentation files  (the
 * "Software"), to  deal in  the Software without  restriction, including
 * without limitation  the rights to  use, copy, modify,  merge, publish,
 * distribute,  sublicense, and/or sell  copies of  the Software,  and to
 * permit persons to whom the Software  is furnished to do so, subject to
 * the following conditions:
 *
 * The  above  copyright  notice  and  this permission  notice  shall  be
 * included in all copies or substantial portions of the Software.
 *
 * THE  SOFTWARE IS  PROVIDED  "AS  IS", WITHOUT  WARRANTY  OF ANY  KIND,
 * EXPRESS OR  IMPLIED, INCLUDING  BUT NOT LIMITED  TO THE  WARRANTIES OF
 * MERCHANTABILITY,    FITNESS    FOR    A   PARTICULAR    PURPOSE    AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE,  ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package fr.opensagres.poi.xwpf.converter.xhtml.internal.styles;

public class CSSStylePropertyConstants
{

    public static final String PADDING_TOP = "padding-top";

    public static final String PADDING_RIGHT = "padding-right";

    public static final String PADDING_LEFT = "padding-left";

    public static final String PADDING_BOTTOM = "padding-bottom";

    public static final String PADDING = "padding";

    public static final String MARGIN_TOP = "margin-top";

    public static final String MARGIN_RIGHT = "margin-right";

    public static final String MARGIN_LEFT = "margin-left";

    public static final String MARGIN_BOTTOM = "margin-bottom";

    public static final String MARGIN = "margin";

    public static final String BORDER_TOP = "border-top";

    public static final String BORDER_TOP_WIDTH = "border-top-width";

    public static final String BORDER_TOP_COLOR = "border-top-color";

    public static final String BORDER_RIGHT = "border-right";

    public static final String BORDER_RIGHT_WIDTH = "border-right-width";

    public static final String BORDER_RIGHT_COLOR = "border-right-color";

    public static final String BORDER_LEFT = "border-left";

    public static final String BORDER_LEFT_WIDTH = "border-left-width";

    public static final String BORDER_LEFT_COLOR = "border-left-color";

    public static final String BORDER_BOTTOM = "border-bottom";

    public static final String BORDER_BOTTOM_WIDTH = "border-bottom-width";

    public static final String BORDER_BOTTOM_COLOR = "border-bottom-color";

    public static final String BORDER = "border";

    public static final String BORDER_COLLAPSE = "border-collapse";

    public static final String BORDER_COLLAPSE_COLLAPSE = "collapse";

    public static final String BORDER_COLLAPSE_SEPARATE = "separate";

    public static final String BACKGROUND_COLOR = "background-color";

    public static final String FONT_FAMILY = "font-family";

    public static final String COLOR = "color";

    public static final String TEXT_INDENT = "text-indent";

    public static final String TEXT_ALIGN = "text-align";

    public static final String TEXT_ALIGN_RIGHT = "right";

    public static final String TEXT_ALIGN_LEFT = "left";

    public static final String TEXT_ALIGN_CENTER = "center";

    public static final String TEXT_ALIGN_JUSTIFIED = "justified";

    public static final String LINE_HEIGHT = "line-height";

    public static final String WIDTH = "width";

    public static final String MIN_WIDTH = "min-width";

    public static final String MAX_WIDTH = "max-width";

    public static final String MAX_HEIGHT = "max-height";

    public static final String VERTICAL_ALIGN = "vertical-align";

    public static final String HEIGHT = "height";

    public static final String MIN_HEIGHT = "min-height";

    public static final String TEXT_DECORATION_UNDERLINE = "underline";

    public static final String TEXT_DECORATION = "text-decoration";

    public static final String FONT_WEIGHT = "font-weight";

    public static final String FONT_WEIGHT_BOLD = "bold";
    
    public static final String FONT_VARIANT = "font-variant";

    public static final String FONT_STYLE = "font-style";

    public static final String FONT_STYLE_ITALIC = "italic";
    
    public static final String FONT_SIZE = "font-size";
    
    public static final String WHITE_SPACE = "white-space";

}

==> fr.opensagres.poi.xwpf.converter.xhtml-2.0.2-sources.jar: fr/opensagres/poi/xwpf/converter/xhtml/internal/styles/CSSStylePropertyConstants.java <==
/**
 * Copyright (C) 2011-2015 The XDocReport Team <xdocreport@googlegroups.com>
 *
 * All rights reserved.
 *
 * Permission is hereby granted, free  of charge, to any person obtaining
 * a  copy  of this  software  and  associated  documentation files  (the
 * "Software"), to  deal in  the Software without  restriction, including
 * without limitation  the rights to  use, copy, modify,  merge, publish,
 * distribute,  sublicense, and/or sell  copies of  the Software,  and to
 * permit persons to whom the Software  is furnished to do so, subject to
 * the following conditions:
 *
 * The  above  copyright  notice  and  this permission  notice  shall  be
 * included in all copies or substantial portions of the Software.
 *
 * THE  SOFTWARE IS  PROVIDED  "AS  IS", WITHOUT  WARRANTY  OF ANY  KIND,
 * EXPRESS OR  IMPLIED, INCLUDING  BUT NOT LIMITED  TO THE  WARRANTIES OF
 * MERCHANTABILITY,    FITNESS    FOR    A   PARTICULAR    PURPOSE    AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE,  ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package fr.opensagres.poi.xwpf.converter.xhtml.internal.styles;

public class CSSStylePropertyConstants
{

    public static final String PADDING_TOP = "padding-top";

    public static final String PADDING_RIGHT = "padding-right";

    public static final String PADDING_LEFT = "padding-left";

    public static final String PADDING_BOTTOM = "padding-bottom";

    public static final String PADDING = "padding";

    public static final String MARGIN_TOP = "margin-top";

    public static final String MARGIN_RIGHT = "margin-right";

    public static final String MARGIN_LEFT = "margin-left";

    public static final String MARGIN_BOTTOM = "margin-bottom";

    public static final String MARGIN = "margin";

    public static final String BORDER_TOP = "border-top";

    public static final String BORDER_TOP_WIDTH = "border-top-width";

    public static final String BORDER_TOP_COLOR = "border-top-color";

    public static final String BORDER_RIGHT = "border-right";

    public static final String BORDER_RIGHT_WIDTH = "border-right-width";

    public static final String BORDER_RIGHT_COLOR = "border-right-color";

    public static final String BORDER_LEFT = "border-left";

    public static final String BORDER_LEFT_WIDTH = "border-left-width";

    public static final String BORDER_LEFT_COLOR = "border-left-color";

    public static final String BORDER_BOTTOM = "border-bottom";

    public static final String BORDER_BOTTOM_WIDTH = "border-bottom-width";

    public static final String BORDER_BOTTOM_COLOR = "border-bottom-color";

    public static final String BORDER = "border";

    public static final String BORDER_COLLAPSE = "border-collapse";

    public static final String BORDER_COLLAPSE_COLLAPSE = "collapse";

    public static final String BORDER_COLLAPSE_SEPARATE = "separate";

    public static final String BACKGROUND_COLOR = "background-color";

    public static final String FONT_FAMILY = "font-family";

    public static final String COLOR = "color";

    public static final String TEXT_INDENT = "text-indent";

    public static final String TEXT_ALIGN = "text-align";

    public static final String TEXT_ALIGN_RIGHT = "right";

    public static final String TEXT_ALIGN_LEFT = "left";

    public static final String TEXT_ALIGN_CENTER = "center";

    public static final String TEXT_ALIGN_JUSTIFIED = "justify";

    public static final String LINE_HEIGHT = "line-height";

    public static final String WIDTH = "width";

    public static final String MIN_WIDTH = "min-width";

    public static final String MAX_WIDTH = "max-width";

    public static final String MAX_HEIGHT = "max-height";

    public static final String VERTICAL_ALIGN = "vertical-align";

    public static final String HEIGHT = "height";

    public static final String MIN_HEIGHT = "min-height";

    public static final String TEXT_DECORATION_UNDERLINE = "underline";

    public static final String TEXT_DECORATION = "text-decoration";

    public static final String FONT_WEIGHT = "font-weight";

    public static final String FONT_WEIGHT_BOLD = "bold";
    
    public static final String FONT_VARIANT = "font-variant";

    public static final String FONT_STYLE = "font-style";

    public static final String FONT_STYLE_ITALIC = "italic";
    
    public static final String FONT_SIZE = "font-size";
    
    public static final String WHITE_SPACE = "white-space";

}
